@@ -17,6 +17,7 @@ class TimesheetLine:
     def __setup__(cls):
         super(TimesheetLine, cls).__setup__()
         cls._error_messages.update({
+                'modify_invoiced_line': 'You can not modify invoiced line.',
                 'delete_invoiced_line': 'You can not delete invoiced line.',
                 })
 
@@ -28,6 +29,12 @@ class TimesheetLine:
         default.setdefault('invoice_line', None)
         return super(TimesheetLine, cls).copy(records, default=default)
 
+    @classmethod
+    def write(cls, *args):
+        if any(l.invoice_line for lines in args[::2] for l in lines):
+            cls.raise_user_error('modify_invoiced_line')
+        super(TimesheetLine, cls).write(*args)
+
     @classmethod
     def delete(cls, records):
         if any(r.invoice_line for r in records):
